@@ -10,30 +10,30 @@ options = (
      {'type' : 'string',
       'default': u"/some/path/to/logo.png",
       'help': 'path to the logo used to build pdfs',
-      'group': 'expense', 'inputlevel': 2,
+      'group': 'expense', 'level': 2,
       }),
     ('company-name',
      {'type' : 'string',
       'default': u"MyCompany",
       'help': 'name of the company editing PDFs',
-      'group': 'expense', 'inputlevel': 2,
+      'group': 'expense', 'level': 2,
       }),
     ('company-address',
      {'type' : 'string',
       'default': u"1, Rue du chat qui pêche - 75005 Paris",
       'help': 'address of the company editing PDFs',
-      'group': 'expense', 'inputlevel': 2,
+      'group': 'expense', 'level': 2,
       }),
     ('company-offnum',
      {'type' : 'string',
       'default': u"123.456.789.00011",
       'help': 'official ID number of the company editing PDFs',
-      'group': 'expense', 'inputlevel': 2,
+      'group': 'expense', 'level': 2,
       }),
     ('company-actnum',
      {'type' : 'string',
       'default': u"101AZ",
       'help': 'activity number of the company editing PDFs',
-      'group': 'expense', 'inputlevel': 2,
+      'group': 'expense', 'level': 2,
       }),
     )
